@@ -1,7 +1,9 @@
 package Video::Xine::Stream;
 
-use Video::Xine;
+use strict;
+use warnings;
 
+use Video::Xine;
 use DateTime;
 
 use base 'Exporter';
@@ -100,6 +102,9 @@ our @EXPORT_OK = qw/
   XINE_META_INFO_CDINDEX_DISCID
   XINE_META_INFO_TRACK_NUMBER
 
+  XINE_MASTER_SLAVE_PLAY
+  XINE_MASTER_SLAVE_STOP
+  XINE_MASTER_SLAVE_SPEED
 /;
 
 # xine_get_stream_info
@@ -266,6 +271,13 @@ our %EXPORT_TAGS = (
           XINE_SPEED_FAST_2
           XINE_SPEED_FAST_4
           /
+    ],
+    master_slave_constants => [
+    	qw/
+		  XINE_MASTER_SLAVE_PLAY
+		  XINE_MASTER_SLAVE_STOP
+		  XINE_MASTER_SLAVE_SPEED
+    	/
     ]
 );
 
@@ -318,6 +330,12 @@ use constant {
     XINE_SPEED_FAST_4 => 16,
 };
 
+use constant {
+	XINE_MASTER_SLAVE_PLAY  => (1<<0),
+	XINE_MASTER_SLAVE_STOP  => (1<<1),
+	XINE_MASTER_SLAVE_SPEED => (1<<2)
+};
+
 sub new {
     my $type = shift;
     my ( $xine, $audio_port, $video_port ) = @_;
@@ -336,6 +354,13 @@ sub new {
 
 }
 
+sub master_slave {
+	my $self = shift;
+	my ( $slave, $affinity ) = @_;
+	
+	return xine_stream_master_slave($self->{'stream'}, $slave, $affinity);
+}
+
 sub get_video_port {
     $_[0]->{'video_port'};
 }
@@ -380,6 +405,15 @@ sub close {
     xine_close( $self->{'stream'} );
 }
 
+##
+## Eject, if possible
+##
+sub eject {
+	my $self = shift;
+	
+	return xine_eject( $self->{'stream'} );
+}
+
 sub get_pos_length {
     my $self = shift;
     my ( $pos_stream, $pos_time, $length_time ) = ( 0, 0, 0 );
@@ -485,6 +519,14 @@ are optional and default to automatically-selected drivers.
 
  Returns the video port, also known as the video driver.
 
+=head3 master_slave()
+
+  $stream->master_slave( $slave_stream, $affection )
+
+Sets up a master-slave relationship with $slave_stream. You can import the constants
+for C<$affection> with the ':master_slave_constants' tag. They are XINE_MASTER_SLAVE_PLAY,
+XINE_MASTER_SLAVE_STOP, and XINE_MASTER_SLAVE_SPEED.
+
 =head3 open()
 
  $stream->open($mrl)
@@ -510,6 +552,12 @@ Stops the stream.
 
 Close the stream. You can re-use the same stream again and again.
 
+=head3 eject()
+
+  $stream->eject()
+  
+Eject the stream, if possible. Returns 1 if OK, 0 if error.
+
 =head3 get_pos_length()
 
   ($pos_pct, $pos_time, $length_time) = $s->get_pos_length();
@@ -913,6 +961,8 @@ XINE_META_INFO_CDINDEX_DISCID
 
 XINE_META_INFO_TRACK_NUMBER
 
+=back
+
 =head1 SEE ALSO
 
 L<Video::Xine>
